@@ -1031,26 +1031,6 @@ class DevObject(object):
         return self.obj[id]
 
 
-class DevPopupWindow(tk.Toplevel):
-    def __init__(self, master, widget: tk.Widget):
-        """
-        这个组件有些不稳定，还在研发当中，请谨慎使用
-
-        :param master:
-        :param wiget:
-        """
-        super(DevPopupWindow, self).__init__(master=master)
-        self.overrideredirect(True)
-        self.withdraw()
-        widget.bind("<Button-1>", lambda event: self.popup(widget.winfo_x() + widget.winfo_width(),
-                                                           widget.winfo_y() + widget.winfo_height()))
-        self.bind("<Button-3>", lambda event: self.withdraw())
-
-    def popup(self, x=0, y=0):
-        self.deiconify()
-        self.geometry(f"+{x}+{y}")
-
-
 class DevBorder(object):
     def __init__(self, widget: tk.Widget = None, iswindow: bool = True, border_color="#e1e1e1"):
         self.widget = widget
@@ -1469,9 +1449,24 @@ class DevToplevel(tk.Toplevel, DevWindow):
         self.iconbitmap(Icon_Empty)
 
 
+class DevPopup(DevToplevel):
+    def __init__(self, master=None, border: bool = True):
+        super(DevPopup, self).__init__(master=master)
+        self.withdraw()
+        if border:
+            window_border(self)
+        if not border:
+            self.overrideredirect(True)
+
+    def popup(self, x, y):
+        self.deiconify()
+        self.geometry(f"+{x}+{y}")
+        self.bind("<FocusOut>", self.withdraw)
+
+
 class DevTooltip(DevToplevel):
     def __init__(self, widget: tk.Widget, window: tk.Tk, message: str = "", after: int = 1000, border: bool = True,
-                 padding: int = 3, side=tk.CENTER, height: int = 40,
+                 padding: int = 3, side=tk.CENTER, height: int = 40, cursor: bool = False, width=None,
                  background="#ffffff", foreground="#000000"):
 
         """
@@ -1496,16 +1491,18 @@ class DevTooltip(DevToplevel):
 
         self.widget = widget
         self.window = window
+        self._width = width
         self._height = height
         self._afterms = after
         self.side = side
         self.padding = padding
+        self._curser = cursor
 
         self.ison = False
         self.border = border
 
-        self.widget.bind("<Enter>", lambda evt: self.show())
-        self.widget.bind("<Leave>", lambda evt: self.hide())
+        self.widget.bind("<Enter>", lambda evt: self.show(evt))
+        self.widget.bind("<Leave>", lambda evt: self.hide(evt))
 
         self.geometry(f"{self.widget.winfo_width()}x{self._height}")
 
@@ -1531,7 +1528,7 @@ class DevTooltip(DevToplevel):
     def message(self, text: str):
         self._message.configure(text=text)
 
-    def hide(self):
+    def hide(self, evt=None):
         """
         内置函数，用于隐藏窗口
         """
@@ -1539,16 +1536,22 @@ class DevTooltip(DevToplevel):
         self.window.deiconify()
         self.withdraw()
 
-    def show(self):
+    def show(self, evt=None):
         """
         内置函数，用于显示窗口
         """
         self.ison = True
 
         def on():
-            self.geometry(f"{self.widget.winfo_width()}x{self._height}")
+            if self._width is None:
+                self.geometry(f"{self.widget.winfo_width()}x{self._height}")
+            elif self._width:
+                self.geometry(f"{self._width}x{self._height}")
             if self.ison:
-                if self.side == "center":
+                if self._curser:
+                    self.geometry(
+                        f"+{round(evt.x) - round(self.winfo_width() / 2)}+{self.widget.winfo_rooty() + self.widget.winfo_height() + 5}")
+                else:
                     if self.border:
                         self.geometry(
                             f"+{self.widget.winfo_rootx() - 7}+{self.widget.winfo_rooty() + self.widget.winfo_height() + 5}")
@@ -1562,5 +1565,5 @@ class DevTooltip(DevToplevel):
 
 if __name__ == '__main__':
     Window = DevWindow()
-    Window.create_titlebar_with_show(title="Hello")
+    DevTooltip(Window, Window, cursor=True, width=100)
     Window.mainloop()
