@@ -37,6 +37,12 @@ ID_ADD = "add"
 ID_MODIFY = "modify"
 ID_DELETE = "delete"
 
+import os
+
+
+def Is64Windows():
+    return 'PROGRAMFILES(X86)' in os.environ
+
 
 def download_winico():
     """
@@ -56,7 +62,12 @@ def download_winico():
             print("开始下载")
 
             def Get_Data():
-                Url = "https://xiangqinxi.github.io/Winico/Winico64.zip"
+                if Is64Windows():
+                    Url = "https://tkdev-docs.netlify.app/_files/Winico64.zip"
+                elif not Is64Windows():
+                    Url = "https://tkdev-docs.netlify.app/_files/Winico32.zip"
+                else:
+                    Url = "https://tkdev-docs.netlify.app/_files/Winico64.zip"
                 Response = requests.get(Url)
                 return Url, Response.content
 
